tabular_v1

Function tabular_v1 

pub fn tabular_v1() -> ArtifactFormat
Standard format for tabular data artifacts.

Any parser for a tabular source format (CSV, TSV, Excel, Parquet, …) should publish artifacts with this format so that generic tabular writers, compaction rules, and extractors can consume them without knowing the source format.