pub struct StructuredDocument {
pub value: Value,
pub format: String,
pub source: Value,
}Expand description
Generic format-neutral value tree. Codec type for structured_document_v1.
All source formats transcode their content into a single serde_json::Value
tree; format records the origin (“json”, “yaml”, “toml”, …) and source
is an open bag of serialization facts (key order, indentation, BOM, trailing
newline) that consumers ignore when unknown.
Fields
value: Valueformat: Stringsource: ValueTrait Implementations
Sourceimpl Clone for StructuredDocument
impl Clone for StructuredDocument
Sourcefn clone(&self) -> StructuredDocument
fn clone(&self) -> StructuredDocument
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructuredDocument
impl Debug for StructuredDocument
Sourceimpl<'de> Deserialize<'de> for StructuredDocument
impl<'de> Deserialize<'de> for StructuredDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for StructuredDocument
impl PartialEq for StructuredDocument
Sourcefn eq(&self, other: &StructuredDocument) -> bool
fn eq(&self, other: &StructuredDocument) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StructuredDocument
impl Serialize for StructuredDocument
impl StructuralPartialEq for StructuredDocument