pub struct TabularParseConfig {
pub header: bool,
pub delimiter: Option<String>,
pub dialect: Option<CsvDialectConfig>,
pub header_line: Option<usize>,
pub skip_lines: Option<usize>,
pub records_path: Option<String>,
}Fields
header: booldelimiter: Option<String>dialect: Option<CsvDialectConfig>header_line: Option<usize>skip_lines: Option<usize>records_path: Option<String>JSON record collection path for document formats that need to expose a nested array as the tabular record stream.