pub fn tabular_v1() -> ArtifactFormatExpand description
Standard format for tabular data artifacts.
Any parser for a tabular source format (CSV, TSV, Excel, Parquet, …) should publish artifacts with this format so that generic tabular writers, compaction rules, and extractors can consume them without knowing the source format.