pub fn tabular_v1() -> ArtifactFormatExpand description
Standard format for tabular data artifacts.
Any comparator that parses a tabular source format (CSV, TSV, Excel, Parquet, …) should publish artifacts with this format so that generic tabular transformers and extractors can consume them without knowing the source format.